==> haskell-bifunctors-5.4.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.4.1
id: bifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176
key: bifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.Tannen Data.Bifunctor.TH
    Data.Bifunctor.Wrapped Data.Bifoldable Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
abi: e4e08b9d3a88eeaa66d7fac02d63c378
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bifunctors-5.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bifunctors-5.4.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/bifunctors-5.4.1
hs-libraries: HSbifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176
depends:
    base-4.9.0.0 base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    comonad-5-1roHbXsedY6KUNYFgPJLp6 containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.4.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.4.1
id: bifunctors-5.4.1-LxooPbwcZDP8AMIXsIu3An
key: bifunctors-5.4.1-LxooPbwcZDP8AMIXsIu3An
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.Tannen Data.Bifunctor.TH
    Data.Bifunctor.Wrapped Data.Bifoldable Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
abi: 510fc378c407d19a4277657255d517d4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bifunctors-5.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bifunctors-5.4.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/bifunctors-5.4.1
hs-libraries: HSbifunctors-5.4.1-LxooPbwcZDP8AMIXsIu3An
depends:
    base-4.9.0.0 base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    comonad-5-32c0CBnUQitJOjClwXgxTu containers-0.5.7.1
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
